========================================
Welcome to oslo.service's documentation!
========================================

Library for running OpenStack services

.. toctree::
   :maxdepth: 1

   installation
   usage
   contributing
   history

API Documentation
=================

.. toctree::
   :maxdepth: 2

   api/eventlet_backdoor
   api/loopingcall
   api/periodic_task
   api/service
   api/sslutils
   api/systemd
   api/threadgroup

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _oslo: https://wiki.openstack.org/wiki/Oslo
